summaryrefslogtreecommitdiffstats
path: root/chrome/installer/util/google_chrome_distribution.cc
diff options
context:
space:
mode:
Diffstat (limited to 'chrome/installer/util/google_chrome_distribution.cc')
-rw-r--r--chrome/installer/util/google_chrome_distribution.cc13
1 files changed, 8 insertions, 5 deletions
diff --git a/chrome/installer/util/google_chrome_distribution.cc b/chrome/installer/util/google_chrome_distribution.cc
index 157f3e1..5922382 100644
--- a/chrome/installer/util/google_chrome_distribution.cc
+++ b/chrome/installer/util/google_chrome_distribution.cc
@@ -119,13 +119,16 @@ int GetDirectoryWriteAgeInHours(const wchar_t* path) {
return (now_time - dir_time);
}
// Launches again this same process with a single switch --|flag|=|value|.
// Does not wait for the process to terminate.
-bool RelaunchSetup(const std::wstring& flag, int value, bool system_install) {
+bool RelaunchSetup(const std::wstring& flag, int value,
+ bool system_level_toast) {
CommandLine cmd_line(CommandLine::ForCurrentProcess()->GetProgram());
cmd_line.AppendSwitchWithValue(WideToASCII(flag), IntToWString(value));
- if (system_install)
- cmd_line.AppendSwitch(WideToASCII(installer_util::switches::kSystemLevel));
+ if (system_level_toast)
+ cmd_line.AppendSwitch(
+ WideToASCII(installer_util::switches::kSystemLevelToast));
return base::LaunchApp(cmd_line, false, false, NULL);
}
@@ -464,7 +467,7 @@ void GoogleChromeDistribution::UpdateDiffInstallStatus(bool system_install,
// 1- Is a per-user-install and it updated: perform the experiment
// 2- Is a system-install and it updated : relaunch as the interactive user
// 3- It has been re-launched from the #2 case. In this case we enter
-// this function with |system_install| false.
+// this function with |system_install| true and a REENTRY_SYS_UPDATE status.
void GoogleChromeDistribution::LaunchUserExperiment(
installer_util::InstallStatus status, const installer::Version& version,
bool system_install) {
@@ -119,13 +119,16 @@ int GetDirectoryWriteAgeInHours(const wchar_t* path) {
return (now_time - dir_time);
}
-// Launches again this same process with a single switch --|flag|=|value|.
+// Launches again this same process with switch --|flag|=|value|.
+// If system_level_toast is true, appends --system-level-toast.
// Does not wait for the process to terminate.